# Changelog

## [0.1.0a1](https://github.com/OpenVoiceOS/ovos-ocp-rss-plugin/tree/0.1.0a1) (2025-04-02)

[Full Changelog](https://github.com/OpenVoiceOS/ovos-ocp-rss-plugin/compare/0.0.3...0.1.0a1)

**Merged pull requests:**

- feat: more metadata [\#5](https://github.com/OpenVoiceOS/ovos-ocp-rss-plugin/pull/5) ([JarbasAl](https://github.com/JarbasAl))



\* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
